@@ -34,6 +34,36 @@ def plotMat(matrix,name='plotMat',saveDir="plotMat",title='Matrix Plot', xlabel=
     plt.savefig(outpath)
     plt.close()
 
+import matplotlib.pyplot as plt
+from shancx import crDir
+import datetime
+def plotMatplus(matrix, name='plotMat', saveDir="plotMat", title='Matrix Plot', 
+           xlabel='Longitude', ylabel='Latitude', color_label='Value', 
+           cmap='viridis', extent=None):
+    """
+    extent: [lon_min, lon_max, lat_min, lat_max]
+    """
+    now_str = datetime.datetime.now().strftime("%Y%m%d%H%M%S")    
+    plt.imshow(matrix, cmap=cmap, origin='upper', aspect='auto', extent=extent)
+    plt.colorbar(label=color_label)
+    plt.title(title)
+    
+    # 添加度符号和方向标识
+    plt.xlabel(f'{xlabel} (°E)')  # 东经
+    plt.ylabel(f'{ylabel} (°N)')  # 北纬
+    
+    plt.tight_layout()
+    outpath = f'./{saveDir}/{name}_{now_str}.png' if name=="plotMat" else f"./{saveDir}/{name}.png"
+    crDir(outpath)
+    plt.savefig(outpath)
+    plt.close()
+"""
+latlon = [10.0, 37.0, 105.0, 125.0] 
+latmin, latmax, lonmin, lonmax = latlon 
+plotMatplus(data,extent=[lon_min, lon_max, lat_min, lat_max]) 
+"""
+
+
 import datetime
 from hjnwtx.colormap import cmp_hjnwtx
 from shancx import crDir
