@@ -34,9 +34,9 @@ print_handler.setFormatter(formatter)
 loggers.addHandler(print_handler)
 
 
-from pathlib import Path
+from pathlib import Path as PathlibPath
 def crDir(path):
-    path_obj = Path(path)
+    path_obj = PathlibPath(path)
     directory = path_obj.parent if path_obj.suffix else path_obj
     directory.mkdir(parents=True, exist_ok=True) 
 
@@ -143,7 +143,6 @@ def Mul_subT(task, param_list, num=3, timeout=3600):
             sys.exit(1)    
     return results
 
-
 from concurrent.futures import ProcessPoolExecutor as PoolExecutor, as_completed, TimeoutError
 import sys
 from tqdm import tqdm
